﻿#region Using Statements

using Microsoft.WindowsAzure.Storage;
using Microsoft.WindowsAzure.Storage.Blob;
using System;
using System.Text;
using System.Threading;
using Windows.Media.Capture;
using Windows.Media.MediaProperties;
using Windows.Storage;
using Windows.UI.Xaml.Controls;

#endregion

namespace IOTUSBCameraAzureStorage
{
    /// <summary>
    /// MainPage for our application.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        #region Fields

        // Timer information.
        private Timer imageCaptureTimer;
        private TimeSpan imageCaptureTimerInterval = new TimeSpan(0, 15, 0); // 15 Minutes.

        // Azure Account information.
        private string azureStorageAccount = "iotusbcameraazurestorageaccount";
        private string azureStoragePrimaryKey = "KXlM0LsABAjsi9aqQcxN9nOYRTbphlrZ4DtUDbf/dGPdiz3ghpMslR9CZOS6MPwX5zEXE9uenBzfsnf/fkL69w==";
        private string azureStorageContainer = "iotusbcamerastoragecontainer";

        private MediaCapture mediaCapture;

        #endregion

        #region Constructors

        /// <summary>
        /// Default Constructor.
        /// </summary>
        public MainPage()
        {
            this.InitializeComponent();

            // Call the initialize method.
            this.initialize();

            // Configure and Start the Timer.
            this.imageCaptureTimer = new Timer(this.imageCaptureTimerExecuted, new object(), this.imageCaptureTimerInterval, this.imageCaptureTimerInterval);
        }

        #endregion

        #region Methods

        private async void initialize()
        {
            // Create a new instance of a MediaCapture object and Initialize it Asynchronously.
            this.mediaCapture = new MediaCapture();
            await this.mediaCapture.InitializeAsync();

            // Set the CaptureElement's Source.
            this.previewElement.Source = this.mediaCapture;

            // Call the StartPreviewAsync method of the MediaCapture.
            await this.mediaCapture.StartPreviewAsync();
        }

        private string buildDateTimeStamp()
        {
            // Create a StringBuilder to hold the time stamp value.
            StringBuilder sb = new StringBuilder();

            // Store the current DateTime.
            DateTime currentDate = DateTime.Now;

            // Add the Year to the StringBuilder.
            sb.Append(currentDate.Year.ToString());

            // Add the Month to the StringBuilder.
            if (currentDate.Month.ToString().Length == 1)
                sb.Append("0" + currentDate.Month.ToString());
            else
                sb.Append(currentDate.Month.ToString());

            // Add the Day to the StringBuilder.
            if (currentDate.Day.ToString().Length == 1)
                sb.Append("0" + currentDate.Day.ToString());
            else
                sb.Append(currentDate.Day.ToString());

            // Add the Hour to the StringBuilder.
            if (currentDate.Hour.ToString().Length == 1)
                sb.Append("0" + currentDate.Hour.ToString());
            else
                sb.Append(currentDate.Hour.ToString());

            // Add the Minute to the StringBuilder.
            if (currentDate.Minute.ToString().Length == 1)
                sb.Append("0" + currentDate.Minute.ToString());
            else
                sb.Append(currentDate.Minute.ToString());

            // Add the Second to the StringBuilder.
            if (currentDate.Second.ToString().Length == 1)
                sb.Append("0" + currentDate.Second.ToString());
            else
                sb.Append(currentDate.Second.ToString());

            // Return the value.
            return sb.ToString();
        }

        private async void imageCaptureTimerExecuted(object sender)
        {
            // Photo StorageFile.
            StorageFile photoFile;

            // Photo file name.
            string photoFileName = this.buildDateTimeStamp() + ".jpg";

            // Create the PhotoFile in the PicturesLibrary System folder.
            photoFile = await KnownFolders.PicturesLibrary.CreateFileAsync(photoFileName, CreationCollisionOption.ReplaceExisting);

            // Create an ImageEncodingProperties object for the photo file.
            ImageEncodingProperties imageProperties = ImageEncodingProperties.CreateJpeg();

            // Using the MediaCapture, capture the photo and save it to the PicturesLibrary System folder.
            await this.mediaCapture.CapturePhotoToStorageFileAsync(imageProperties, photoFile);

            // Create an Azure CloudStorageAccount object.
            CloudStorageAccount storageAccount = CloudStorageAccount.Parse("DefaultEndpointsProtocol=https;AccountName=" + this.azureStorageAccount + ";AccountKey=" + this.azureStoragePrimaryKey);

            // Create a CloudBlobClient object using the CloudStorageAccount.
            CloudBlobClient blobClient = storageAccount.CreateCloudBlobClient();

            // Create a CloudBlobContain object using the CloudBlobClient.
            CloudBlobContainer container = blobClient.GetContainerReference(this.azureStorageContainer);

            //  Create a CloudBlockBlob using the CloudBlobContainer.
            CloudBlockBlob blockBlob = container.GetBlockBlobReference(photoFileName);

            //  Using the CloudBlockBlob, Upload the file to Azure.
            await blockBlob.UploadFromFileAsync(photoFile);
        }

        #endregion
    }
}
